
/*  Copyright (C) 1995-1996 Andrew Davison

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

/* Usage:
     modtime [file|directory]

   Date: May 1st, 1996

   Sets the modification field of each html file to the current
   time using the UNIX touch utility.

   If supplied with a directory, it recursively applies itself to all
   the html files in the tree. 

   Author: Andrew Davison

   Address (May 1996):
   The Department of Computer Science
   The University of Melbourne
   Parkville, Victoria 3052, Australia
   Email: ad@cs.mu.oz.au
   Tel: +61 3 287 9172
   Fax: +61 3 348 1184
   URL: http://www.cs.mu.oz.au/~ad
*/

#include <stdio.h>
#include <string.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <ftw.h>

#define PATHLEN	100

int set_mods(const char *fname, const struct stat *status, int type);
void set_mod(const char *fname);
int html_cmp(const char *fname);

int main(int argc, char *argv[])
{
  struct stat stbuf;

  if (argc == 1)
    ftw(".", set_mods, 1);     /* using current directory */
  else if (argc == 2) {
      if (stat(argv[1], &stbuf) == -1) {
        printf("Cannot read stat structure for %s\n", argv[1]);
        return (-1);
      }
      if ((stbuf.st_mode & S_IFMT) == S_IFDIR)  /* argv[1] is dir */
        ftw(argv[1], set_mods, 1); 
      else {
        if (html_cmp(argv[1]) == 0)
          set_mod(argv[1]);        /* argv[1] is a HTML file */
        else
          printf("Ignoring %s since it does not end with .html\n", argv[1]);
      }
  }
  else {
    printf("Wrong number of arguments. Usage: modtime [file|directory]\n");
  }
  return 0;
}


int set_mods(const char *fname, const struct stat *status, int type)
/* If fname is a HTML file then apply set_mod() to it. */
/* set_mods() is called by ftw() for every object in a directory.
   See p.74-76 of UNIX System Programming */
{
  if (type == FTW_F)                   /* fname is a file */
    if (html_cmp(fname) == 0)     /* fname is a HTML file */
      set_mod(fname);
  /*  else
        printf("Ignoring %s since it does not end with .html\n", fname); */
  return 0;
}


void set_mod(const char *fname)
/* Set the modification time field of the file to
   the current time using touch. */
{
  char cmd[PATHLEN];

  printf("Updating modification time of %s\n", fname);
  sprintf(cmd, "touch %s", fname);
  system(cmd);
}


int html_cmp(const char *fname)
/* Compare the file name end with "html" */
{
  int i=0;     

  if (fname[0] == '.') 
    i = 1;       /* to skip possible "." at beginning */
  while ((fname[i] != '\0') && (fname[i] != '.'))
    i++;
  if (fname[i] == '.')
    return strcmp(&fname[i+1], "html");
  else
    return 1;
}

