
/*  Copyright (C) 1995-1996 Andrew Davison

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

/* Usage:
      no_link filename.gif

   Date: May 1st, 1996

   Creates a GIF file called no_filename.gif which
   has a red cross through the image. This means
   that the GIF is *not* linked to a page.

   Makes use of the gd graphics library, by
   Thomas Boutell and the Quest Protein Database Center 
   at Cold Spring Harbor Labs.
   COPYRIGHT 1994,1995 BY THE QUEST PROTEIN DATABASE CENTER 
   AT COLD SPRING HARBOR LABS.
*/

/* compile using: gcc -o no_link no_link.c -lgd -lm
*/

/* Author: Andrew Davison

   Address (May 1996):
   The Department of Computer Science
   The University of Melbourne
   Parkville, Victoria 3052, Australia
   Email: ad@cs.mu.oz.au
   Tel: +61 3 9287 9172
   Fax: +61 3 9348 1184
   URL: http://www.cs.mu.oz.au/~ad
*/


#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <gd.h>     /* may vary depending on location of gd headers */
                    /* I use: #include "/home/staff/ad/gd1.2/gd.h" */

int main(int argc, char *argv[])
/* arg[1] is the filename */
{
  int xlen, ylen, red;
  gdImagePtr im, brush;
  char *nofnm;
  FILE *fp;

  if (argc != 2) {
    printf("Usage: no_link gif-filename.gif\n");
    exit (-1);
  }

  if ((fp = fopen(argv[1], "rb")) == NULL) {
    printf("Cannot read %s\n", argv[1]);
    exit(1);
  }
  im = gdImageCreateFromGif(fp);
  fclose(fp);
  xlen = im->sx;
  ylen = im->sy;

  brush = gdImageCreate(3,3);
  red = gdImageColorAllocate(brush, 255, 0, 0);

  gdImageSetBrush(im, brush);
  gdImageLine(im, 0, 0, xlen-1,  ylen-1, gdBrushed);
  gdImageLine(im, 0, ylen-1, xlen-1, 0, gdBrushed);

  nofnm = (char *)malloc(sizeof(char)*(strlen(argv[1])+4));
  sprintf(nofnm, "no_%s", argv[1]);
  /* printf("nofnm is %s\n", nofnm); */

  if ((fp = fopen(nofnm, "wb")) == NULL)
    printf("Cannot write to %s\n", nofnm);
  else {
    printf("Writing red-crossed image to %s\n", nofnm);
    gdImageGif(im, fp);
    fclose(fp);
  }

  gdImageDestroy(im);
  gdImageDestroy(brush);
  return 0;
}

